@@ -46,6 +46,10 @@ class Client:
     j = {"send_status": {"id": msg_id, "msg": msg}}
     self._send(Client._encode_json(j))
 
+  def send_info(self, msg):
+    j = {"send_info": msg}
+    self._send(Client._encode_json(j))
+
   def send_error(self, msg):
     j = {"send_warning": msg}
     self._send(Client._encode_json(j))
@@ -54,7 +58,7 @@ class Client:
     j = {"store_in_memory": values_dict}
     self._send(Client._encode_json(j))
     
-  def read_cells(self, keys_arr, buffer_size=0):
+  def read_cells(self, keys_arr, buffer_size=8192):
     j = {"memory_cells": keys_arr}
     j = Client._decode_json(self._accept(Client._encode_json(j), buffer_size))
     if "memory_values" not in j:
